/*
DL2 Monitor: ./lib/monpa.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (monpa): Monitor and Anlyzer Definitions (internal)
 *
 * This header isn't considered to belong to the library API, but to define
 * some notions which are in common to the Monitor and Analyzer executables.
 * Therefore, this file has been placed in the lib/ directory.
 *
 * Most of the definitions refer to names in the rcfile which are commonly
 * used by the Monitor and Analyzer. The Dl2_Monheader structure defines some
 * settings to identify the nature of Monitor output. 
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020501  DL2_VERSION_DATE, DL2_COPYRIGHT: introduced.
 * 20020501  DL2_VERSION: package version introduced.
 * 20020410  Use of shared memory introduced.
 * 20020408  Dl2_Monheader introduced, precedes monitor data.
 * 20020408  network interface introduced.
 * 20020404  created from scratch
 * $Id: monpa.h,v 1.6 2002/05/02 07:55:32 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __MONPA_H__
# define __MONPA_H__

// package version number:
# define DL2_VERSION_NO  (double)1.0
# define DL2_VERSION_DATE  "20020501"
# define DL2_COPYRIGHT  "Copyright 2002 Rolf Jger, Ulm (Germany)"

// default file names:
# define DL2_RCFILE	".dl2monrc"
# define DL2_DEFMONOUT	"/tmp/dl2mon"
# define DL2_ENVIRON	"DL2MON_DIR"

// dl2monrc definitions:
# define DL2_COMMENT_MARK	'#'
# define DL2_PACKETT_MARK	':'
# define DL2_PARAMST_MARK	'='
# define DL2_KEY_SOCKTYPE	"socket-type"
# define DL2_KEY_MONOUT		"mon-output"
# define DL2_KEY_PAOUT		"pa-output"
# define DL2_KEY_PROTOCOL	"protocol"
# define DL2_KEY_INTERFACE	"interface"

# define DL2_KEY_SOCKTYPE_raw	"raw"
# define DL2_KEY_SOCKTYPE_RAW	DL2_KEY_SOCKTYPE_raw
# define DL2_KEY_SOCKTYPE_dgram	"datagram"
# define DL2_KEY_SOCKTYPE_DGRAM	DL2_KEY_SOCKTYPE_dgram
# define DL2_KEY_PROTOCOL_all	"all"
# define DL2_KEY_PROTOCOL_ALL	DL2_KEY_PROTOCOL_all
# define DL2_KEY_PROTOCOL_ppp	"pppoe"
# define DL2_KEY_PROTOCOL_PPP	DL2_KEY_PROTOCOL_ppp
# define DL2_KEY_PROTOCOL_pppd	"pppoe-d"
# define DL2_KEY_PROTOCOL_PPPD	DL2_KEY_PROTOCOL_pppd
# define DL2_KEY_PROTOCOL_ppps  "pppoe-s"
# define DL2_KEY_PROTOCOL_PPPS  DL2_KEY_PROTOCOL_ppps
# define DL2_KEY_INTERFACE_eth0 "eth0"
# define DL2_KEY_INTERFACE_ETH0 DL2_KEY_INTERFACE_eth0

// commonly use option identifiers:
# define DL2_OPT_USAGEM	"-?"
# define DL2_OPT_RCFILE	"-C"
# define DL2_OPT_FLAGS	"-F"

// 16-Byte header in monitor data:
typedef struct Dl2_Monheader {
  int socket_type;
  unsigned short protocol;
  char interface[10];  
} Dl2_Monheader __attribute__ ((packed));

// (SV) shared memory objects:
# define DL2_SHMPATHNAME	"/tmp/dl2mon.shm"
# define DL2_SHMV_MODE		0660
# define DL2_SHMF_monup		0x00000001
# define DL2_SHMF_paup		0x00000002
# define DL2_SHMF_readheader	0x00000004

typedef struct Dl2_Monpashm {
  int monpid, papid, flags;
  Dl2_Monheader header;
} Dl2_Monpashm;

# endif /*__MONPA_H__*/
